| inputIsCorrect | R Documentation |
Check the correctness of the input provided by the User
inputIsCorrect(listOfInput, data, message = FALSE)
listOfInput |
A |
data |
A reactive |
message |
|
This function checks if the numeric and character input is not empty as well as checks numeric values for being integers.
Returns TRUE if all input is correct, otherwise, returns FALSE.
If messages=TRUE the function returns the message to the User with appropriate instruction.
Alina Tselinina tselinina@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.